@@ -10,6 +10,11 @@
 #define NSTDAPI
 #endif
 #ifdef __cplusplus
-#define NSTDCPP
+#define NSTDCPP __cplusplus
+#define NSTDCPPSTART extern "C" {
+#define NSTDCPPEND }
+#else
+#define NSTDCPPSTART
+#define NSTDCPPEND
 #endif
 #endif
